@@ -1,5 +1,5 @@
 /*****************************************************************************
-** $Id: qt/qgfxlinuxfb_qws.cpp   3.3.2   edited Jun 23 2003 $
+** $Id: qt/qgfxlinuxfb_qws.cpp   3.3.4   edited Oct 4 11:44 $
 **
 ** Implementation of QLinuxFbScreen (unaccelerated Linux framebuffer) class for
 ** Embedded Qt
@@ -207,11 +207,28 @@ bool QLinuxFbScreen::connect( const QString &displaySpec )
 		  malloc(sizeof(unsigned short int)*screencols);
 	startcmap->transp=(unsigned short int *)
 		    malloc(sizeof(unsigned short int)*screencols);
-	ioctl(fd,FBIOGETCMAP,startcmap);
+	if (ioctl(fd,FBIOGETCMAP,startcmap)) {
+            perror("reading fb cmap");
+            qWarning("Error reading palette from framebuffer");
+        }
+	int bits_used = 0;
 	for(loopc=0;loopc<screencols;loopc++) {
 	    screenclut[loopc]=qRgb(startcmap->red[loopc] >> 8,
 				   startcmap->green[loopc] >> 8,
 				   startcmap->blue[loopc] >> 8);
+	    bits_used |= startcmap->red[loopc]
+			 | startcmap->green[loopc]
+			 | startcmap->blue[loopc];
+	}
+	// WORKAROUND: Some framebuffer drivers only return 8 bit
+	// color values, so we need to not bit shift them..
+	if ((bits_used & 0x00ff) && !(bits_used & 0xff00)) {
+	    for(loopc=0;loopc<screencols;loopc++) {
+		screenclut[loopc] = qRgb(startcmap->red[loopc],
+					 startcmap->green[loopc],
+					 startcmap->blue[loopc]);
+	    }
+	    qWarning("8 bits cmap returned due to faulty FB driver, colors corrected");
 	}
     } else {
 	screencols=0;
@@ -454,7 +471,10 @@ bool QLinuxFbScreen::initDevice()
 	    cmap.blue[i] = i*65535/((1<<bbits)-1);
 	    cmap.transp[i] = 0;
 	}
-	ioctl(fd,FBIOPUTCMAP,&cmap);
+	if (ioctl(fd,FBIOPUTCMAP,&cmap)) {
+            perror("writing fb cmap");
+            qWarning("Error writing palette to framebuffer");
+        }
 	free(cmap.red);
 	free(cmap.green);
 	free(cmap.blue);
@@ -473,16 +493,16 @@ bool QLinuxFbScreen::initDevice()
 	*lowest=mapsize;
 	insert_entry(*entryp,*lowest,*lowest);  // dummy entry to mark start
     }
-
-    shared->fifocount=0;
-    shared->buffer_offset=0xffffffff;  // 0 would be a sensible offset (screen)
-    shared->linestep=0;
-    shared->cliptop=0xffffffff;
-    shared->clipleft=0xffffffff;
-    shared->clipright=0xffffffff;
-    shared->clipbottom=0xffffffff;
-    shared->rop=0xffffffff;
-
+    if (shared) {
+        shared->fifocount=0;
+        shared->buffer_offset=0xffffffff;  // 0 would be a sensible offset (screen)
+        shared->linestep=0;
+        shared->cliptop=0xffffffff;
+        shared->clipleft=0xffffffff;
+        shared->clipright=0xffffffff;
+        shared->clipbottom=0xffffffff;
+        shared->rop=0xffffffff;
+    }
     *optype=0;
     *lastop=0;
 
