@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qgfxmach64_qws.cpp   3.3.2   edited May 27 2003 $
+** $Id: qt/qgfxmach64_qws.cpp   3.3.4   edited Sep 24 14:38 $
 **
 ** Implementation of QGfxMach64 (graphics context) class for Mach64 cards
 *
@@ -201,7 +201,7 @@ inline unsigned int QGfxMach64<depth,type>::regr2(volatile unsigned int
 template<const int depth,const int type>
 inline void QGfxMach64<depth,type>::wait_for_fifo(short entries)
 {
-    QLinuxFb_Shared * tmp=(QLinuxFb_Shared *)shared_data;
+    QLinuxFb_Shared * tmp=(QLinuxFb_Shared *)this->shared_data;
     tmp->fifocount+=entries;
     if(tmp->fifocount<tmp->fifomax)
 	return;
@@ -291,7 +291,7 @@ QGfxMach64<depth,type>::QGfxMach64(unsigned char * a,int b,int c)
 template<const int depth,const int type>
 inline void QGfxMach64<depth,type>::do_scissors(QRect & r)
 {
-    QLinuxFb_Shared * tmp=(QLinuxFb_Shared *)shared_data;
+    QLinuxFb_Shared * tmp=(QLinuxFb_Shared *)this->shared_data;
     if(tmp->clipleft!=r.left()) {
       tmp->clipleft=r.left();
       wait_for_fifo(1);
@@ -375,18 +375,18 @@ inline bool QGfxMach64<depth,type>::checkSourceDest()
 
     int sourcepixelpitch;
     ulong src_buffer_offset;
-    if (srctype == SourcePen) {
+    if (this->srctype == QGfx::SourcePen) {
 	src_buffer_offset = -1;
 	return FALSE;
     } else {
-	if (!gfx_screen->onCard(srcbits,src_buffer_offset)) {
+	if (!this->gfx_screen->onCard(this->srcbits,src_buffer_offset)) {
 	    return FALSE;
 	}
 	if(src_buffer_offset & 0x7) {
 	    qDebug("Unaligned offset %lx",src_buffer_offset);
 	    return FALSE;
 	}
-	sourcepixelpitch=(srclinestep*8)/srcdepth;
+	sourcepixelpitch=(this->srclinestep*8)/this->srcdepth;
 	wait_for_fifo(1);
 	regw(SRC_OFF_PITCH,( (sourcepixelpitch / 8 ) << 22) |
 	     (src_buffer_offset / 8) );
@@ -404,16 +404,16 @@ template<const int depth,const int type>
 inline void QGfxMach64<depth,type>::setDest()
 {
     ulong buffer_offset;
-    gfx_screen->onCard(buffer,buffer_offset);
-    QLinuxFb_Shared * tmp=(QLinuxFb_Shared *)shared_data;
-    if(tmp->buffer_offset==buffer_offset && tmp->linestep==linestep()) {
+    this->gfx_screen->onCard(this->buffer,buffer_offset);
+    QLinuxFb_Shared * tmp=(QLinuxFb_Shared *)this->shared_data;
+    if(tmp->buffer_offset==buffer_offset && tmp->linestep==this->linestep()) {
       return;
     } else {
       tmp->buffer_offset=buffer_offset;
-      tmp->linestep=linestep();
+      tmp->linestep=this->linestep();
     }
 
-    int pixelstep=(linestep()*8)/depth;
+    int pixelstep=(this->linestep()*8)/depth;
     setPixWidth(depth,depth);
     wait_for_fifo(1);
     regw(DST_OFF_PITCH,(( pixelstep / 8 ) << 22) | (buffer_offset / 8));
@@ -423,11 +423,11 @@ template<const int depth,const int type>
 void QGfxMach64<depth,type>::drawLine(int x1,int y1,int x2,int y2)
 {
     // No point going any further if the window isn't visible
-    if(ncliprect<1)
+    if(this->ncliprect<1)
         return;
 
     // Only handle 'normal' lines
-    if ( cpen.style() != SolidLine || myrop!=CopyROP ) {
+    if ( this->cpen.style() != QGfx::SolidLine || this->myrop!=Qt::CopyROP ) {
 	QGfxRaster<depth,type>::drawLine(x1,y1,x2,y2);
 	return;
     }
@@ -442,11 +442,11 @@ void QGfxMach64<depth,type>::drawLine(int x1,int y1,int x2,int y2)
 
     GFX_START(QRect(x1, y1 < y2 ? y1 : y2, dx+1, QABS(dy)+1))
 
-    if((*gfx_optype)!=1 || (*gfx_lastop)!=LASTOP_LINE) {
+    if((*this->gfx_optype)!=1 || (*this->gfx_lastop)!=LASTOP_LINE) {
 	setDest();
 	// The scaler engine operates independently of the 2d engine
 	// so we need to wait for it to finish if it's doing something
-	if((*gfx_optype)>1)
+	if((*this->gfx_optype)>1)
 	    wait_for_idle();
 
 	// This is avoided if the last operation was a line
@@ -454,20 +454,20 @@ void QGfxMach64<depth,type>::drawLine(int x1,int y1,int x2,int y2)
 	regw(DP_SRC,0x00000100);
 	regw(DP_MIX,(MIX_SRC << 16) | MIX_DST);
 
-	(*gfx_lastop)=LASTOP_LINE;
+	(*this->gfx_lastop)=LASTOP_LINE;
     }
 
     // Note that the last operation used the 2d engine
-    (*gfx_optype)=1;
+    (*this->gfx_optype)=1;
 
     int loopc;
 
     // Add the offset of the gfx - used to make the origin the right
     // place for windows
-    x1=x1+xoffs;
-    y1=y1+yoffs;
-    x2=x2+xoffs;
-    y2=y2+yoffs;
+    x1=x1+this->xoffs;
+    y1=y1+this->yoffs;
+    x2=x2+this->xoffs;
+    y2=y2+this->yoffs;
 
     // Only cope with lines going from left to right
     // - swap them round if this isn't true
@@ -487,9 +487,9 @@ void QGfxMach64<depth,type>::drawLine(int x1,int y1,int x2,int y2)
 
 #ifndef QT_NO_QWS_REPEATER
     QScreen * tmp=qt_screen;
-    qt_screen=gfx_screen;
+    qt_screen=this->gfx_screen;
 #endif
-    QColor c=cpen.color();
+    QColor c=this->cpen.color();
     unsigned int tmpcol=c.alloc();
 #ifndef QT_NO_QWS_REPEATER
     qt_screen=tmp;
@@ -502,7 +502,7 @@ void QGfxMach64<depth,type>::drawLine(int x1,int y1,int x2,int y2)
     // these rectangles and re-draw the line - an alternative approach
     // would be to clip to the rectangle in software
 
-    for(loopc=0;loopc<ncliprect;loopc++) {
+    for(loopc=0;loopc<this->ncliprect;loopc++) {
 	// Code taken from Mach64 Programmer's Manual
         // Sets up Bresenham parameters
 	int mindelta,maxdelta;
@@ -526,7 +526,7 @@ void QGfxMach64<depth,type>::drawLine(int x1,int y1,int x2,int y2)
 	unsigned int rval=0x00000003;
 	rval=(rval & ~0x7) | (unsigned long)(ymajor | ydir | xdir);
 
-	do_scissors(cliprect[loopc]);
+	do_scissors(this->cliprect[loopc]);
 
 	wait_for_fifo(6);
 	regw(DST_CNTL,rval);
@@ -551,30 +551,30 @@ void QGfxMach64<depth,type>::drawLine(int x1,int y1,int x2,int y2)
 template<const int depth,const int type>
 void QGfxMach64<depth,type>::fillRect(int rx,int ry,int w,int h)
 {
-    if(ncliprect<1) {
+    if(this->ncliprect<1) {
 	return;
     }
 
-    if( (cbrush.style()!=NoBrush) && (cbrush.style()!=SolidPattern) ) {
+    if( (this->cbrush.style()!=QBrush::NoBrush) && (this->cbrush.style()!=QBrush::SolidPattern) ) {
 	QGfxRaster<depth,type>::fillRect(rx,ry,w,h);
 	return;
     }
 
-    if(myrop!=CopyROP) {
+    if(this->myrop!=Qt::CopyROP) {
 	QGfxRaster<depth,type>::fillRect(rx,ry,w,h);
 	return;
     }
 
-    GFX_START(QRect(rx+xoffs, ry+yoffs, w+1, h+1))
+    GFX_START(QRect(rx+this->xoffs, ry+this->yoffs, w+1, h+1))
     setDest();
 
-    if((*gfx_optype)!=1 || (*gfx_lastop)!=LASTOP_RECT) {
+    if((*this->gfx_optype)!=1 || (*this->gfx_lastop)!=LASTOP_RECT) {
 
 	// probably not needed
 	// we reset the clip rectangle because we do our own software
 	// clipping (rectangle<->rectangle intersections are fast)
 
-        QRect tmprect(0,0,width,height);
+        QRect tmprect(0,0,this->width,this->height);
         do_scissors(tmprect);
 
         wait_for_fifo(3);
@@ -582,17 +582,17 @@ void QGfxMach64<depth,type>::fillRect(int rx,int ry,int w,int h)
         regw(DP_MIX,(MIX_SRC << 16) | MIX_DST);
         regw(DST_CNTL,0x00000003);
 
-	(*gfx_lastop)=LASTOP_RECT;
+	(*this->gfx_lastop)=LASTOP_RECT;
     }
 
-    if((*gfx_optype)>1)
+    if((*this->gfx_optype)>1)
 	sync();
-    (*gfx_optype)=1;
+    (*this->gfx_optype)=1;
 
     int loopc;
 
-    int xp=rx+xoffs;
-    int yp=ry+yoffs;
+    int xp=rx+this->xoffs;
+    int yp=ry+this->yoffs;
 
     int x2,y2;
 
@@ -601,26 +601,26 @@ void QGfxMach64<depth,type>::fillRect(int rx,int ry,int w,int h)
 
     int x3,y3,x4,y4;
 
-    QColor tmp=cbrush.color();
+    QColor tmp=this->cbrush.color();
     wait_for_fifo(1);
 
 #ifndef QT_NO_QWS_REPEATER
     QScreen * tmp2=qt_screen;
-    qt_screen=gfx_screen;
+    qt_screen=this->gfx_screen;
 #endif
     regw(DP_FRGD_CLR,tmp.alloc());
 #ifndef QT_NO_QWS_REPEATER
     qt_screen=tmp2;
 #endif
 
-    if(cbrush.style()!=NoBrush) {
-	int p=ncliprect;
+    if(this->cbrush.style()!=QBrush::NoBrush) {
+	int p=this->ncliprect;
 	if(p<8) {
 	    // We can wait for all our fifos at once
 	    // (slight performance optimisation)
 	    wait_for_fifo(p*2);
 	    for(loopc=0;loopc<p;loopc++) {
-		QRect r=cliprect[loopc];
+		QRect r=this->cliprect[loopc];
 		// Clip rectangle to current clip rectangle
 		if(xp<=r.right() && yp<=r.bottom() &&
 		   x2>=r.left() && y2>=r.top()) {
@@ -635,7 +635,7 @@ void QGfxMach64<depth,type>::fillRect(int rx,int ry,int w,int h)
 	    }
 	} else {
 	    for(loopc=0;loopc<p;loopc++) {
-		QRect r=cliprect[loopc];
+		QRect r=this->cliprect[loopc];
 		if(xp<=r.right() && yp<=r.bottom() &&
 		   x2>=r.left() && y2>=r.top()) {
 		    x3=r.left() > xp ? r.left() : xp;
@@ -659,13 +659,13 @@ void QGfxMach64<depth,type>::fillRect(int rx,int ry,int w,int h)
 template<const int depth,const int type>
 inline void QGfxMach64<depth,type>::blt(int rx,int ry,int w,int h,int sx, int sy)
 {
-    if(ncliprect<1)
+    if(this->ncliprect<1)
 	return;
 
     // We have no provision for cacheing these things in graphics card
     // memory at the moment
-    if(alphatype==BigEndianMask || alphatype==LittleEndianMask ||
-       alphatype==SeparateAlpha || srctype==SourcePen || (myrop!=CopyROP) ) {
+    if(this->alphatype==QGfx::BigEndianMask || this->alphatype==QGfx::LittleEndianMask ||
+       this->alphatype==QGfx::SeparateAlpha || this->srctype==QGfx::SourcePen || (this->myrop!=Qt::CopyROP) ) {
 	QGfxRaster<depth,type>::blt(rx,ry,w,h,sx,sy);
     }
 
@@ -675,27 +675,27 @@ inline void QGfxMach64<depth,type>::blt(int rx,int ry,int w,int h,int sx, int sy
     // and a texture. Textures have to be a power of 2 in sizes so the
     // pixmap has to be the right size in order for this to be accelerated.
     // Also, only 32 bit source textures are alpha-blended in hardware
-    if(srcdepth==32) {
-	if(alphatype==IgnoreAlpha || alphatype==SolidAlpha ||
-	   alphatype==InlineAlpha) {
+    if(this->srcdepth==32) {
+	if(this->alphatype==QGfx::IgnoreAlpha || this->alphatype==QGfx::SolidAlpha ||
+	   this->alphatype==QGfx::InlineAlpha) {
 	    canaccel=true;
 	}
 
-	if(alphatype!=IgnoreAlpha) {
+	if(this->alphatype!=QGfx::IgnoreAlpha) {
 	    // Mach64 requires textures to be these sizes
-	    int p=srclinestep/4;
+	    int p=this->srclinestep/4;
 	    if(p!=1024 && p!=512 && p!=256 && p!=128 && p!=64 && p!=32 &&
 	       p!=16 && p!=8) {
 		canaccel=false;
 	    }
 	}
-    } else if(srcdepth==16 || srcdepth==8) {
-	if(alphatype==IgnoreAlpha) {
+    } else if(this->srcdepth==16 || this->srcdepth==8) {
+	if(this->alphatype==QGfx::IgnoreAlpha) {
 	    canaccel=true;
 	}
     }
 
-    if(srctype==SourceImage && canaccel==false) {
+    if(this->srctype==QGfx::SourceImage && canaccel==false) {
 	QGfxRaster<depth,type>::blt(rx,ry,w,h,sx,sy);
 	return;
     }
@@ -703,13 +703,13 @@ inline void QGfxMach64<depth,type>::blt(int rx,int ry,int w,int h,int sx, int sy
     // We can't handle 'real' alpha blending with a solid pen source
     // (this would be a separate alpha channel, as in anti-aliased text,
     // or possibly a solid alpha value)
-    if(srctype==SourcePen && !(alphatype==BigEndianMask ||
-			       alphatype==LittleEndianMask) ) {
+    if(this->srctype==QGfx::SourcePen && !(this->alphatype==QGfx::BigEndianMask ||
+			       this->alphatype==QGfx::LittleEndianMask) ) {
 	QGfxRaster<depth,type>::blt(rx,ry,w,h,sx,sy);
 	return;
     }
 
-    if( (srcdepth!=32) && (srcdepth!=16) && (srcdepth!=8) ) {
+    if( (this->srcdepth!=32) && (this->srcdepth!=16) && (this->srcdepth!=8) ) {
 	QGfxRaster<depth,type>::blt(rx,ry,w,h,sx,sy);
 	return;
     }
@@ -718,7 +718,7 @@ inline void QGfxMach64<depth,type>::blt(int rx,int ry,int w,int h,int sx, int sy
     GFX_START(cursRect);
     bool check_result=checkSourceDest();
 
-    if( (alphatype==InlineAlpha || alphatype==SolidAlpha)
+    if( (this->alphatype==QGfx::InlineAlpha || this->alphatype==QGfx::SolidAlpha)
 	&& check_result ) {
 	int x2=(rx+w)-1;
 	int y2=(ry+h)-1;
@@ -733,15 +733,15 @@ inline void QGfxMach64<depth,type>::blt(int rx,int ry,int w,int h,int sx, int sy
 
         // This is now a normal 2d engine blt
 
-	int xp=xoffs+rx;
-	int yp=yoffs+ry;
-	int xp2=srcwidgetoffs.x() + sx;
-	int yp2=srcwidgetoffs.y() + sy;
+	int xp=this->xoffs+rx;
+	int yp=this->yoffs+ry;
+	int xp2=this->srcwidgetoffs.x() + sx;
+	int yp2=this->srcwidgetoffs.y() + sy;
 
-	if(srctype==SourceImage) {
+	if(this->srctype==QGfx::SourceImage) {
 
-	    if((*gfx_optype)!=1 || (*gfx_lastop)!=LASTOP_BLT) {
-		(*gfx_lastop)=LASTOP_BLT;
+	    if((*this->gfx_optype)!=1 || (*this->gfx_lastop)!=LASTOP_BLT) {
+		(*this->gfx_lastop)=LASTOP_BLT;
 		wait_for_fifo(8);
 		// Write to all bits of the pixel
 		regw(DP_WRITE_MASK,0xffffffff);
@@ -754,7 +754,7 @@ inline void QGfxMach64<depth,type>::blt(int rx,int ry,int w,int h,int sx, int sy
 
 	    // Set up graphics engine's idea of source and destination
 	    // pixel sizes
-	    setPixWidth(depth,srcdepth);
+	    setPixWidth(depth,this->srcdepth);
 	    // Tell the engine whether to copy bits from left to right,
 	    // top to bottom, right to left, bottom to top - this is
 	    // important for getting the right results with an overlapping
@@ -792,14 +792,14 @@ inline void QGfxMach64<depth,type>::blt(int rx,int ry,int w,int h,int sx, int sy
 	} else {
 	    // This is used for drawing a solid colour with a mask -
 	    // used for brushes
-	    if((*gfx_optype)!=1 || (*gfx_lastop)!=LASTOP_BLTPEN) {
-		setPixWidth(depth,srcdepth,16,alphatype==LittleEndianMask);
-		QColor tmp=cpen.color();
+	    if((*this->gfx_optype)!=1 || (*this->gfx_lastop)!=LASTOP_BLTPEN) {
+		setPixWidth(depth,this->srcdepth,16,this->alphatype==QGfx::LittleEndianMask);
+		QColor tmp=this->cpen.color();
 		wait_for_fifo(8);
 		regw(DP_WRITE_MASK,0xffffffff);
 #ifndef QT_NO_QWS_REPEATER
 		QScreen * tmp2=qt_screen;
-		qt_screen=gfx_screen;
+		qt_screen=this->gfx_screen;
 #endif
 		regw(DP_FRGD_CLR,tmp.alloc());
 #ifndef QT_NO_QWS_REPEATER
@@ -811,18 +811,18 @@ inline void QGfxMach64<depth,type>::blt(int rx,int ry,int w,int h,int sx, int sy
 		regw(SRC_CNTL,0x00000004);
 		regw(DST_CNTL,0x00000003);
 		regw(SRC_Y_X,0);
-		(*gfx_lastop)=LASTOP_BLTPEN;
+		(*this->gfx_lastop)=LASTOP_BLTPEN;
 	    }
 	}
 
-	(*gfx_optype)=1;
+	(*this->gfx_optype)=1;
 
 	int loopc;
-	for(loopc=0;loopc<ncliprect;loopc++) {
+	for(loopc=0;loopc<this->ncliprect;loopc++) {
 
   	    // Now it's all set up, repeatedly set the scissors
 	    // and perform the blt
-	    do_scissors(cliprect[loopc]);
+	    do_scissors(this->cliprect[loopc]);
 
 	    wait_for_fifo(3);
 	    regw(SRC_WIDTH1,w);
@@ -850,10 +850,10 @@ void QGfxMach64<depth,type>::stretchBlt(int rx,int ry,int w,int h,
 					int sw,int sh)
 {
     // This doesn't use the 2d engine, it uses the 3d/scaler pipeline
-    if(ncliprect<1)
+    if(this->ncliprect<1)
 	return;
 
-    if(srctype!=SourceImage) {
+    if(this->srctype!=QGfx::SourceImage) {
 	QGfxRaster<depth,type>::stretchBlt(rx,ry,w,h,sw,sh);
 	return;	
     }
@@ -861,39 +861,39 @@ void QGfxMach64<depth,type>::stretchBlt(int rx,int ry,int w,int h,
     QRect cursRect(rx, ry, w+1, h+1);
     GFX_START(cursRect);
 
-    if ( srctype!=SourceImage || !checkSourceDest() ) {
+    if ( this->srctype!=QGfx::SourceImage || !checkSourceDest() ) {
 	GFX_END
 	QGfxRaster<depth,type>::stretchBlt(rx,ry,w,h,sw,sh);
 	return;
     }
 
-    (*gfx_lastop)=LASTOP_STRETCHBLT;
+    (*this->gfx_lastop)=LASTOP_STRETCHBLT;
 
-    if((*gfx_optype)!=2)
+    if((*this->gfx_optype)!=2)
 	wait_for_idle();
-    (*gfx_optype)=2;
+    (*this->gfx_optype)=2;
 
-    int xp=xoffs+rx;
-    int yp=yoffs+ry;
+    int xp=this->xoffs+rx;
+    int yp=this->yoffs+ry;
 
     int loopc;
-    for(loopc=0;loopc<ncliprect;loopc++) {
+    for(loopc=0;loopc<this->ncliprect;loopc++) {
 
 	wait_for_fifo(3);
 	regw(SCALE_3D_CNTL,0x00000040);
 	regw(ALPHA_TEST_CNTL,0);
 	regw(TEX_CNTL,0);
-	if(srclinestep<1)
+	if(this->srclinestep<1)
 	    abort();
 
 	// We need the offset from the start of video memory for a
 	// different register than SRC_BUFFER_OFFSET
 	unsigned long my_src_buffer_offset;
-	if (!gfx_screen->onCard(srcbits,my_src_buffer_offset))
+	if (!this->gfx_screen->onCard(this->srcbits,my_src_buffer_offset))
 	    qFatal("checkSourceDest() lied!");
 
-	int srcpixelpitch=srclinestep;
-	srcpixelpitch=(srcpixelpitch*8)/srcdepth;
+	int srcpixelpitch=this->srclinestep;
+	srcpixelpitch=(srcpixelpitch*8)/this->srcdepth;
 	srcpixelpitch=srcpixelpitch >> 3;
 	srcpixelpitch=srcpixelpitch << 3;
 
@@ -920,13 +920,13 @@ void QGfxMach64<depth,type>::stretchBlt(int rx,int ry,int w,int h,
 	// therefore we twiddle the y starting position of the buffer
 	// to put it inside the clip rectangle
 
-	int sy1=cliprect[loopc].top();
+	int sy1=this->cliprect[loopc].top();
 
 	double mytmp=sy1-yp;
 	mytmp*=screentosource;
 
 	int add=(int)mytmp;
-	add=add*srclinestep;
+	add=add*this->srclinestep;
 
 	my_src_buffer_offset+=add;
 
@@ -947,7 +947,7 @@ void QGfxMach64<depth,type>::stretchBlt(int rx,int ry,int w,int h,
 	regw(SECONDARY_SCALE_HACC,0x00000000);
 	regw(SECONDARY_SCALE_VACC,0x00000000);
 
-	setPixWidth(depth,srcdepth);
+	setPixWidth(depth,this->srcdepth);
 
 	wait_for_fifo(9);
 	regw(SCALE_X_INC,h1 << 4);
@@ -964,7 +964,7 @@ void QGfxMach64<depth,type>::stretchBlt(int rx,int ry,int w,int h,
 	regw(CLR_CMP_CNTL,0x02000000);
 	regw(DST_CNTL,0x00000003);
 
-	do_scissors(cliprect[loopc]);
+	do_scissors(this->cliprect[loopc]);
 
 	regw(DST_X,xp);
 	regw(DST_Y,sy1);
@@ -1000,22 +1000,22 @@ void QGfxMach64<depth,type>::sync()
 template<const int depth,const int type>
 void QGfxMach64<depth,type>::tiledBlt(int rx,int ry,int w,int h)
 {
-    if(ncliprect<1) {
+    if(this->ncliprect<1) {
 	return;
     }
 
-    if(srctype==SourceImage && (alphatype!=IgnoreAlpha) ) {
+    if(this->srctype==QGfx::SourceImage && (this->alphatype!=QGfx::IgnoreAlpha) ) {
 	QGfxRaster<depth,type>::tiledBlt(rx,ry,w,h);
 	return;
     }
 
-    if( (srcdepth!=16 && srcdepth!=32 && srcdepth!=8)
-	  && srctype==SourceImage ) {
+    if( (this->srcdepth!=16 && this->srcdepth!=32 && this->srcdepth!=8)
+	  && this->srctype==QGfx::SourceImage ) {
 	QGfxRaster<depth,type>::tiledBlt(rx,ry,w,h);
 	return;
     }
 
-    if ( srctype==SourcePen ) {
+    if ( this->srctype==QGfx::SourcePen ) {
 	QGfxRaster<depth,type>::tiledBlt(rx,ry,w,h);
 	return;
     }
@@ -1023,49 +1023,49 @@ void QGfxMach64<depth,type>::tiledBlt(int rx,int ry,int w,int h)
     QRect cursRect(rx, ry, w+1, h+1);
     GFX_START(cursRect);
 
-    if ( srctype==SourceImage && !checkSourceDest() ) {
+    if ( this->srctype==QGfx::SourceImage && !checkSourceDest() ) {
 	GFX_END
 	QGfxRaster<depth,type>::tiledBlt(rx,ry,w,h);
 	return;
     }
 
 
-    int xp=xoffs+rx;
-    int yp=yoffs+ry;
+    int xp=this->xoffs+rx;
+    int yp=this->yoffs+ry;
 
-    if(srctype==SourceImage) {
-	if((*gfx_optype)!=1 || (*gfx_lastop)!=LASTOP_TILEDBLT) {
+    if(this->srctype==QGfx::SourceImage) {
+	if((*this->gfx_optype)!=1 || (*this->gfx_lastop)!=LASTOP_TILEDBLT) {
 	    wait_for_fifo(4);
 	    regw(SRC_CNTL,0x00000003);
 	    regw(DP_WRITE_MASK,0xffffffff);
 	    regw(CLR_CMP_CNTL,0x00000000);
 	    regw(DST_CNTL,0x00000003);
-	    if(srcdepth==16 || srcdepth==32 || srcdepth==8) {
-		setPixWidth(depth,srcdepth);
+	    if(this->srcdepth==16 || this->srcdepth==32 || this->srcdepth==8) {
+		setPixWidth(depth,this->srcdepth);
 		wait_for_fifo(3);
 		regw(DP_MIX,0x00070003);
 		regw(DP_SRC,0x00000300);
 		regw(DP_FRGD_CLR,0xffffffff);
 	    } else {
-		setPixWidth(depth,1,1,!src_little_endian);
+		setPixWidth(depth,1,1,!this->src_little_endian);
 		wait_for_fifo(4);
 		regw(DP_MIX,0x00070007);
 		regw(DP_SRC,0x00030100);
-		regw(DP_FRGD_CLR,srcclut[0]);
-		regw(DP_BKGD_CLR,srcclut[1]);
+		regw(DP_FRGD_CLR,this->srcclut[0]);
+		regw(DP_BKGD_CLR,this->srcclut[1]);
 	    }
-	    (*gfx_lastop)=LASTOP_TILEDBLT;
+	    (*this->gfx_lastop)=LASTOP_TILEDBLT;
 	}
     } else {
-	if((*gfx_optype)!=1 || (*gfx_lastop)!=LASTOP_TILEDBLTPEN) {
-	    setPixWidth(depth,1,1,alphatype==LittleEndianMask);
+	if((*this->gfx_optype)!=1 || (*this->gfx_lastop)!=LASTOP_TILEDBLTPEN) {
+	    setPixWidth(depth,1,1,this->alphatype==QGfx::LittleEndianMask);
 	    wait_for_fifo(7);
 	    regw(SRC_CNTL,0x00000001);
 	    regw(DP_WRITE_MASK,0xffffffff);
-	    QColor tmp=cpen.color();
+	    QColor tmp=this->cpen.color();
 #ifndef QT_NO_QWS_REPEATER
 	    QScreen * tmp2=qt_screen;
-	    qt_screen=gfx_screen;
+	    qt_screen=this->gfx_screen;
 #endif
 	    regw(DP_FRGD_CLR,tmp.alloc());
 #ifndef QT_NO_QWS_REPEATER
@@ -1075,13 +1075,13 @@ void QGfxMach64<depth,type>::tiledBlt(int rx,int ry,int w,int h)
 	    regw(DP_SRC,0x00030100);
 	    regw(CLR_CMP_CNTL,0x00000000);
 	    regw(DST_CNTL,0x00000003);
-	    (*gfx_lastop)=LASTOP_TILEDBLTPEN;
+	    (*this->gfx_lastop)=LASTOP_TILEDBLTPEN;
 	}
     }
 
-    (*gfx_optype)=1;
+    (*this->gfx_optype)=1;
 
-    QRect tmprect(0,0,width,height);
+    QRect tmprect(0,0,this->width,this->height);
     do_scissors(tmprect);
 
     int xp2,yp2;
@@ -1090,11 +1090,11 @@ void QGfxMach64<depth,type>::tiledBlt(int rx,int ry,int w,int h)
     yp3=(yp+h)-1;
 
     int loopc;
-    for(loopc=0;loopc<ncliprect;loopc++) {
-	xp2=srcwidgetoffs.x() + brushoffs.x();
-	yp2=srcwidgetoffs.y() + brushoffs.y();
+    for(loopc=0;loopc<this->ncliprect;loopc++) {
+	xp2=this->srcwidgetoffs.x() + this->brushoffs.x();
+	yp2=this->srcwidgetoffs.y() + this->brushoffs.y();
 
-	QRect r=cliprect[loopc];
+	QRect r=this->cliprect[loopc];
 	int myxp=xp > r.left() ? xp : r.left();
 	int myyp=yp > r.top() ? yp : r.top();
 	int myxp2=xp3 > r.right() ? r.right() : xp3;
@@ -1110,23 +1110,23 @@ void QGfxMach64<depth,type>::tiledBlt(int rx,int ry,int w,int h)
 	yp2+=yo;
 
 	while(xp2<0) {
-	    xp2+=srcwidth;
+	    xp2+=this->srcwidth;
 	}
 	while(yp2<0) {
-	    yp2+=srcheight;
+	    yp2+=this->srcheight;
 	}
 
-	while(xp2>srcwidth)
-	    xp2-=srcwidth;
+	while(xp2>this->srcwidth)
+	    xp2-=this->srcwidth;
 
-	while(yp2>srcheight)
-	    yp2-=srcheight;
+	while(yp2>this->srcheight)
+	    yp2-=this->srcheight;
 
 	if(ww2>0 && hh2>0) {
 	    wait_for_fifo(6);
 	    regw(SRC_Y_X_START,0);
-	    regw(SRC_HEIGHT2_WIDTH2,(srcwidth << 16) | srcheight);
-	    regw(SRC_HEIGHT1_WIDTH1,( (srcwidth-xp2) << 16 ) | srcheight-yp2);
+	    regw(SRC_HEIGHT2_WIDTH2,(this->srcwidth << 16) | this->srcheight);
+	    regw(SRC_HEIGHT1_WIDTH1,( (this->srcwidth-xp2) << 16 ) | this->srcheight-yp2);
 	    regw(SRC_Y_X,(xp2 << 16) | yp2);
 	    regw(DST_Y_X,(myxp << 16) | myyp);
 	    regw(DST_HEIGHT_WIDTH,(ww2 << 16) | hh2);
@@ -1166,14 +1166,14 @@ template<const int depth,const int type>
 void QGfxMach64<depth,type>::drawAlpha(int x1,int y1,int x2,int y2,
 				       int x3,int y3,int x4,int y4)
 {
-    if(ncliprect<1) {
+    if(this->ncliprect<1) {
 	return;
     }
 
     if(no3d)
 	return;
 
-    QRect cursRect(x1+xoffs, y1+yoffs, abs(x2-x1)+1, abs(y2-y1)+1);
+    QRect cursRect(x1+this->xoffs, y1+this->yoffs, abs(x2-x1)+1, abs(y2-y1)+1);
     GFX_START(cursRect);
 
     if(!checkSourceDest()) {
@@ -1187,14 +1187,14 @@ void QGfxMach64<depth,type>::drawAlpha(int x1,int y1,int x2,int y2,
     int yy[4];
 
     // 2 fractional bits
-    xx[0]=(x1+xoffs);
-    yy[0]=(y1+yoffs);
-    xx[1]=(x2+xoffs);
-    yy[1]=(y2+yoffs);
-    xx[2]=(x3+xoffs);
-    yy[2]=(y3+yoffs);
-    xx[3]=(x4+xoffs);
-    yy[3]=(y4+yoffs);
+    xx[0]=(x1+this->xoffs);
+    yy[0]=(y1+this->yoffs);
+    xx[1]=(x2+this->xoffs);
+    yy[1]=(y2+this->yoffs);
+    xx[2]=(x3+this->xoffs);
+    yy[2]=(y3+this->yoffs);
+    xx[3]=(x4+this->xoffs);
+    yy[3]=(y4+this->yoffs);
 
     float xs=0.0;
     float ys=0.0;
@@ -1217,12 +1217,12 @@ void QGfxMach64<depth,type>::drawAlpha(int x1,int y1,int x2,int y2,
 	yy[loopc]*=4;
     }
 
-    (*gfx_optype)=2;
-    (*gfx_lastop)=LASTOP_ALPHA;
+    (*this->gfx_optype)=2;
+    (*this->gfx_lastop)=LASTOP_ALPHA;
 
-    for(loopc=0;loopc<ncliprect;loopc++) {
+    for(loopc=0;loopc<this->ncliprect;loopc++) {
 
-	do_scissors(cliprect[loopc]);
+	do_scissors(this->cliprect[loopc]);
 
 	// Used for one-over-area - magic needed by the triangle
 	// setup engine
@@ -1251,7 +1251,7 @@ void QGfxMach64<depth,type>::drawAlpha(int x1,int y1,int x2,int y2,
 	int tfilt=0;
 	int tblend=0;
 	int texalpha=0;
-	if(srcdepth==32 && alphatype==InlineAlpha)
+	if(this->srcdepth==32 && this->alphatype==QGfx::InlineAlpha)
 	    texalpha=1;
 	int split=0;
 
@@ -1287,7 +1287,7 @@ void QGfxMach64<depth,type>::drawAlpha(int x1,int y1,int x2,int y2,
 	    | ( 0 << 31 )           // 1 = source pixel from host register
 	    ;
 
-	setPixWidth(depth,srcdepth,srcdepth);
+	setPixWidth(depth,this->srcdepth,this->srcdepth);
 
 	wait_for_fifo(5);
 	regw(DP_FRGD_CLR,0xffffffff);
@@ -1296,7 +1296,7 @@ void QGfxMach64<depth,type>::drawAlpha(int x1,int y1,int x2,int y2,
 	regw(CLR_CMP_CNTL,0);
 	regw(GUI_TRAJ_CNTL,3);
 
-	int p=srclinestep/4;
+	int p=this->srclinestep/4;
 
 	// Pitch must be a power of 2 (in pixels)
 	int logpitch;
@@ -1320,10 +1320,10 @@ void QGfxMach64<depth,type>::drawAlpha(int x1,int y1,int x2,int y2,
 	    logpitch=0x2;
 	}
 
-	double wfx=srcwidth;
+	double wfx=this->srcwidth;
 	//double wf2=p;  //### not used
 	wfx=wfx/p;
-	double wfy=srcheight;
+	double wfy=this->srcheight;
 	wfy=wfy/p;
 
 	wait_for_fifo(6);
@@ -1332,7 +1332,7 @@ void QGfxMach64<depth,type>::drawAlpha(int x1,int y1,int x2,int y2,
 	     (logpitch << 24));
 
 	unsigned long foffset;
-	if (!gfx_screen->onCard(srcbits,foffset))
+	if (!this->gfx_screen->onCard(this->srcbits,foffset))
 	    qFatal("checkSourceDest() lied!");
 
 	// These registers are used for mip-mapping on Mach64. We don't need
@@ -1373,21 +1373,21 @@ void QGfxMach64<depth,type>::drawAlpha(int x1,int y1,int x2,int y2,
 	regw(DP_SRC,DP_BKGD_SRC_3D | DP_FRGD_SRC_3D | DP_MONO_SRC_1);
 
 	wait_for_fifo(5);
-	regw2(VERTEX_1_ARGB,0x000000ff | calpha << 24);
+	regw2(VERTEX_1_ARGB,0x000000ff | this->calpha << 24);
 	regw2(VERTEX_1_X_Y,xx[0] << 16 | yy[0]);
 	regwf2(VERTEX_1_S,xs);
 	regwf2(VERTEX_1_T,ys);
 	regwf2(VERTEX_1_W,1.0);
 
 	wait_for_fifo(5);
-	regw2(VERTEX_2_ARGB,0x0000ff00 | calpha2 << 24);
+	regw2(VERTEX_2_ARGB,0x0000ff00 | this->calpha2 << 24);
 	regw2(VERTEX_2_X_Y,xx[1] << 16 | yy[1]);
 	regwf2(VERTEX_2_S,wfx);
 	regwf2(VERTEX_2_T,ys);
 	regwf2(VERTEX_2_W,1.0);
 
 	wait_for_fifo(5);
-	regw2(VERTEX_3_ARGB,0x00ff0000 | calpha4 << 24);
+	regw2(VERTEX_3_ARGB,0x00ff0000 | this->calpha4 << 24);
 	regw2(VERTEX_3_X_Y,xx[2] << 16 | yy[2]);
 	regwf2(VERTEX_3_S,xs);
 	regwf2(VERTEX_3_T,wfy);
@@ -1397,7 +1397,7 @@ void QGfxMach64<depth,type>::drawAlpha(int x1,int y1,int x2,int y2,
 
 	wait_for_fifo(6);
 
-	regw2(VERTEX_1_ARGB,0x000000ff | calpha3 << 24);
+	regw2(VERTEX_1_ARGB,0x000000ff | this->calpha3 << 24);
 	regw2(VERTEX_1_X_Y,xx[3] << 16 | yy[3]);
 	regwf2(VERTEX_1_S,wfx);
 	regwf2(VERTEX_1_T,wfy);
