@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qgfxmatrox_qws.cpp   3.3.2   edited Jan 22 14:56 $
+** $Id: qt/qgfxmatrox_qws.cpp   3.3.4   edited Sep 24 14:38 $
 **
 ** Implementation of QGfxMatrox (graphics context) class for Matrox MGA cards
 **
@@ -123,37 +123,37 @@ private:
 template<const int depth,const int type>
 inline unsigned int QGfxMatrox<depth,type>::getRop(Qt::RasterOp r)
 {
-  if(r==CopyROP) {
+  if(r==QGfx::CopyROP) {
     return 0xc;
-  } else if(r==OrROP) {
+  } else if(r==QGfx::OrROP) {
     return 0xe;
-  } else if(r==XorROP) {
+  } else if(r==QGfx::XorROP) {
     return 0x6;
-  } else if(r==NotAndROP) {
+  } else if(r==QGfx::NotAndROP) {
     return 0x4;
-  } else if(r==NotCopyROP) {
+  } else if(r==QGfx::NotCopyROP) {
     return 0x3;
-  } else if(r==NotOrROP) {
+  } else if(r==QGfx::NotOrROP) {
     return 0xd;
-  } else if(r==NotXorROP) {
+  } else if(r==QGfx::NotXorROP) {
     return 0x9;
-  } else if(r==AndROP) {
+  } else if(r==QGfx::AndROP) {
     return 0x8;
-  } else if(r==NotROP) {
+  } else if(r==QGfx::NotROP) {
     return 0x5;
-  } else if(r==ClearROP) {
+  } else if(r==QGfx::ClearROP) {
     return 0x0;
-  } else if(r==SetROP) {
+  } else if(r==QGfx::SetROP) {
     return 0xf;
-  } else if(r==NopROP) {
+  } else if(r==QGfx::NopROP) {
     return 0xa;
-  } else if(r==AndNotROP) {
+  } else if(r==QGfx::AndNotROP) {
     return 0x2;
-  } else if(r==OrNotROP) {
+  } else if(r==QGfx::OrNotROP) {
     return 0xb;
-  } else if(r==NandROP) {
+  } else if(r==QGfx::NandROP) {
     return 0x7;
-  } else if(r==NorROP) {
+  } else if(r==QGfx::NorROP) {
     return 0x1;
   } else {
     qFatal("Unknown ROP!");
@@ -164,7 +164,7 @@ inline unsigned int QGfxMatrox<depth,type>::getRop(Qt::RasterOp r)
 template<const int depth,const int type>
 inline void QGfxMatrox<depth,type>::do_scissors(QRect & r)
 {
-    int t=linestep();
+    int t=this->linestep();
     t=(t*8)/depth;
 
     matrox_regw(CXLEFT,r.left());
@@ -207,12 +207,12 @@ template<const int depth,const int type>
 inline void QGfxMatrox<depth,type>::setDest()
 {
     ulong buffer_offset;
-    gfx_screen->onCard(buffer,buffer_offset);
+    this->gfx_screen->onCard(this->buffer,buffer_offset);
 
     unsigned int b=(buffer_offset >> 6) << 6;
     b=(b*8)/depth;
 
-    int t=linestep();
+    int t=this->linestep();
     t=(t*8)/depth;
     if(t & 0x1f) {
 	qDebug("Unaligned pixel linestep %d",t);
@@ -221,14 +221,14 @@ inline void QGfxMatrox<depth,type>::setDest()
 
     // fillRect stops working if this isn't done here
     matrox_regw(YTOP,b);
-    matrox_regw(YBOT,(height*t)+b);
+    matrox_regw(YBOT,(this->height*t)+b);
 
-    QLinuxFb_Shared * tmp=(QLinuxFb_Shared *)shared_data;
-    if(tmp->buffer_offset==buffer_offset && tmp->linestep==linestep()) {
+    QLinuxFb_Shared * tmp=(QLinuxFb_Shared *)this->shared_data;
+    if(tmp->buffer_offset==buffer_offset && tmp->linestep==this->linestep()) {
       return;
     } else {
       tmp->buffer_offset=buffer_offset;
-      tmp->linestep=linestep();
+      tmp->linestep=this->linestep();
     }
 
     int d;
@@ -254,10 +254,10 @@ inline bool QGfxMatrox<depth,type>::checkSourceDest()
     setDest();
 
     ulong src_buffer_offset;
-    if (srctype == SourcePen) {
+    if (this->srctype == QGfx::SourcePen) {
 	src_buffer_offset = -1;
     } else {
-	if (!gfx_screen->onCard(srcbits,src_buffer_offset)) {
+	if (!this->gfx_screen->onCard(this->srcbits,src_buffer_offset)) {
 	    return FALSE;
 	}
 	if(src_buffer_offset & 0x7) {
@@ -265,13 +265,13 @@ inline bool QGfxMatrox<depth,type>::checkSourceDest()
 	    return FALSE;
 	}
 	int srcstep;
-	if (srclinestep==0) {
-	    srcstep=(width*srcdepth)/8;
+	if (this->srclinestep==0) {
+	    srcstep=(this->width*this->srcdepth)/8;
 	} else {
-	    srcstep=srclinestep;
+	    srcstep=this->srclinestep;
 	}
 
-	src_pixel_offset=(src_buffer_offset * 8)/depth;
+	this->src_pixel_offset=(src_buffer_offset * 8)/depth;
 
     }
     return TRUE;
@@ -286,25 +286,25 @@ QGfxMatrox<depth,type>::QGfxMatrox(unsigned char * a,int b,int c)
 template<const int depth,const int type>
 void QGfxMatrox<depth,type>::fillRect(int rx,int ry,int w,int h)
 {
-    if(ncliprect<1) {
+    if(this->ncliprect<1) {
 	return;
     }
 
-    if( (cbrush.style()!=NoBrush) && (cbrush.style()!=SolidPattern) ) {
+    if( (this->cbrush.style()!=QBrush::NoBrush) && (this->cbrush.style()!=QBrush::SolidPattern) ) {
 	QGfxRaster<depth,type>::fillRect(rx,ry,w,h);
 	return;
     }
 
-    GFX_START(QRect(rx+xoffs, ry+yoffs, w+1, h+1))
+    GFX_START(QRect(rx+this->xoffs, ry+this->yoffs, w+1, h+1))
     setDest();
 
-    (*gfx_optype)=1;
-    (*gfx_lastop)=LASTOP_RECT;
+    (*this->gfx_optype)=1;
+    (*this->gfx_lastop)=LASTOP_RECT;
 
     int loopc;
 
-    int xp=rx+xoffs;
-    int yp=ry+yoffs;
+    int xp=rx+this->xoffs;
+    int yp=ry+this->yoffs;
 
     int x2,y2;
 
@@ -313,34 +313,34 @@ void QGfxMatrox<depth,type>::fillRect(int rx,int ry,int w,int h)
 
     int x3,y3,x4,y4;
 
-    QColor tmp=cbrush.color();
+    QColor tmp=this->cbrush.color();
 
 #ifndef QT_NO_QWS_REPEATER
     QScreen * tmp2=qt_screen;
-    qt_screen=gfx_screen;
+    qt_screen=this->gfx_screen;
 #endif
     int tmpcol=tmp.alloc();
-    if(((QLinuxFb_Shared *)shared_data)->forecol!=tmpcol) {
+    if(((QLinuxFb_Shared *)this->shared_data)->forecol!=tmpcol) {
         matrox_regw(FCOL,get_color(tmpcol));
-        ((QLinuxFb_Shared *)shared_data)->forecol=tmpcol;
+        ((QLinuxFb_Shared *)this->shared_data)->forecol=tmpcol;
     }
 #ifndef QT_NO_QWS_REPEATER
     qt_screen=tmp2;
 #endif
 
-    (*gfx_optype)=1;
+    (*this->gfx_optype)=1;
 
-    QRect tmprect(0,0,width,height);
+    QRect tmprect(0,0,this->width,this->height);
     do_scissors(tmprect);
 
     // Last in 1d00-1dff range
 
-    unsigned int tmprop=getRop(myrop) << 16;
+    unsigned int tmprop=getRop(this->myrop) << 16;
 
-    if(cbrush.style()!=NoBrush) {
-	int p=ncliprect;
+    if(this->cbrush.style()!=QBrush::NoBrush) {
+	int p=this->ncliprect;
 	for(loopc=0;loopc<p;loopc++) {
-	    QRect r=cliprect[loopc];
+	    QRect r=this->cliprect[loopc];
 	    if(xp<=r.right() && yp<=r.bottom() &&
 	       x2>=r.left() && y2>=r.top()) {
 		x3 = QMAX( r.left(), xp );
@@ -349,7 +349,7 @@ void QGfxMatrox<depth,type>::fillRect(int rx,int ry,int w,int h)
 		y4 = QMIN( r.bottom(), y2 );
 		int hh=(y4-y3)+1;
 		int p=y3;
-		int t=linestep();
+		int t=this->linestep();
 		t=(t*8)/depth;
 		//t&=0x1f;
 		p*=(t >> 5);
@@ -367,11 +367,11 @@ void QGfxMatrox<depth,type>::fillRect(int rx,int ry,int w,int h)
 template<const int depth,const int type>
 void QGfxMatrox<depth,type>::drawLine(int x1,int y1,int x2,int y2)
 {
-    if(ncliprect<1) {
+    if(this->ncliprect<1) {
 	return;
     }
 
-    unsigned int tmprop=getRop(myrop) << 16;
+    unsigned int tmprop=getRop(this->myrop) << 16;
 
     int dx,dy;
     dx=abs(x2-x1);
@@ -380,13 +380,13 @@ void QGfxMatrox<depth,type>::drawLine(int x1,int y1,int x2,int y2)
     GFX_START(QRect(x1, y1 < y2 ? y1 : y2, dx+1, QABS(dy)+1))
     setDest();
 
-    (*gfx_optype)=1;
-    (*gfx_lastop)=LASTOP_LINE;
+    (*this->gfx_optype)=1;
+    (*this->gfx_lastop)=LASTOP_LINE;
 
-    x1+=xoffs;
-    y1+=yoffs;
-    x2+=xoffs;
-    y2+=yoffs;
+    x1+=this->xoffs;
+    y1+=this->yoffs;
+    x2+=this->xoffs;
+    y2+=this->yoffs;
 
     int loopc;
 
@@ -405,24 +405,24 @@ void QGfxMatrox<depth,type>::drawLine(int x1,int y1,int x2,int y2)
 	sgn |= 0x4;
     }
 
-    for(loopc=0;loopc<ncliprect;loopc++) {
-	do_scissors(cliprect[loopc]);
-	QColor tmp=cpen.color();
+    for(loopc=0;loopc<this->ncliprect;loopc++) {
+	do_scissors(this->cliprect[loopc]);
+	QColor tmp=this->cpen.color();
 	QScreen * tmpscreen=qt_screen;
-	qt_screen=gfx_screen;
+	qt_screen=this->gfx_screen;
 	int tmp2=tmp.alloc();
 	qt_screen=tmpscreen;
 
-	if(((QLinuxFb_Shared *)shared_data)->forecol!=tmp2) {
+	if(((QLinuxFb_Shared *)this->shared_data)->forecol!=tmp2) {
 	    matrox_regw(FCOL,tmp2);
-	    ((QLinuxFb_Shared *)shared_data)->forecol=tmp2;
+	    ((QLinuxFb_Shared *)this->shared_data)->forecol=tmp2;
 	}
 
-	if(dashedLines) {
+	if(this->dashedLines) {
 	    unsigned int tmp=0;
-	    for(int loopc=0;loopc<numDashes;loopc++) {
+	    for(int loopc=0;loopc<this->numDashes;loopc++) {
 		// Fill unsigned int with up to 32 bits
-		tmp &= dashes[loopc] << ((loopc % 4) * 8);
+		tmp &= this->dashes[loopc] << ((loopc % 4) * 8);
 		if((loopc % 4)==3) {
 		    // When 4th byte is filled, fill SRC1-3
 		    // with it (these registers are contiguous and
@@ -431,10 +431,10 @@ void QGfxMatrox<depth,type>::drawLine(int x1,int y1,int x2,int y2)
 		    tmp=0;
 		}
 	    }
-	    if(numDashes<4) {
+	    if(this->numDashes<4) {
 		matrox_regw(SRC0,tmp);
 	    }
-	    matrox_regw(SHIFT,((numDashes*8)-1) << 16);
+	    matrox_regw(SHIFT,((this->numDashes*8)-1) << 16);
 	    matrox_regw(DWGCTL,DWG_LINE_CLOSE | tmprop | DWG_BFCOL);	
 	} else {
 	    matrox_regw(DWGCTL,DWG_LINE_CLOSE | tmprop | DWG_SHIFTZERO |
@@ -447,7 +447,7 @@ void QGfxMatrox<depth,type>::drawLine(int x1,int y1,int x2,int y2)
 	matrox_regw(SGN,sgn);
 	matrox_regw(XDST,x1);
 	int p=y1;
-	int t=linestep();
+	int t=this->linestep();
 	t=(t*8)/depth;
 	//t&=0x1f;
 	p*=(t >> 5);
@@ -461,36 +461,36 @@ void QGfxMatrox<depth,type>::drawLine(int x1,int y1,int x2,int y2)
 template<const int depth,const int type>
 inline void QGfxMatrox<depth,type>::blt(int rx,int ry,int w,int h,int sx,int sy)
 {
-    if(ncliprect<1)
+    if(this->ncliprect<1)
 	return;
 
     bool canaccel=false;
 
-    if((srcdepth==32 || srcdepth==16 || srcdepth==8) &&
-       alphatype==IgnoreAlpha) {
+    if((this->srcdepth==32 || this->srcdepth==16 || this->srcdepth==8) &&
+       this->alphatype==QGfx::IgnoreAlpha) {
 	canaccel=true;
     }
 
-    if(srctype==SourceImage && canaccel==false) {
+    if(this->srctype==QGfx::SourceImage && canaccel==false) {
 	QGfxRaster<depth,type>::blt(rx,ry,w,h,sx,sy);
 	return;
     }
 
-    if(srctype==SourcePen) {
+    if(this->srctype==QGfx::SourcePen) {
 	QGfxRaster<depth,type>::blt(rx,ry,w,h,sx,sy);
 	return;
     }
 
-    int xp=xoffs+rx;
-    int yp=yoffs+ry;
+    int xp=this->xoffs+rx;
+    int yp=this->yoffs+ry;
     QRect cursRect(xp, yp, w+1, h+1);
     GFX_START(cursRect)
 
     if(checkSourceDest()) {
 
-	unsigned int tmprop=getRop(myrop) << 16;
-	int xp2=srcwidgetoffs.x() + sx;
-	int yp2=srcwidgetoffs.y() + sy;
+	unsigned int tmprop=getRop(this->myrop) << 16;
+	int xp2=this->srcwidgetoffs.x() + sx;
+	int yp2=this->srcwidgetoffs.y() + sy;
 
 	int mx = QMIN(xp,xp2);
 	if ( mx < 0 ) {
@@ -502,36 +502,36 @@ inline void QGfxMatrox<depth,type>::blt(int rx,int ry,int w,int h,int sx,int sy)
 	}
 
 
-	(*gfx_optype)=1;
-	(*gfx_lastop)=LASTOP_BLT;
+	(*this->gfx_optype)=1;
+	(*this->gfx_lastop)=LASTOP_BLT;
 
         bool rev = (yp > yp2) || ((yp == yp2) && (xp > xp2));
 	int dy = (yp > yp2) ? -1 : 1;
 	int dx = (xp > xp2) ? -1 : 1;
 
-	int loopc = (dy<0) ? ncliprect-1 : 0;
+	int loopc = (dy<0) ? this->ncliprect-1 : 0;
 
-	while ( loopc >=0 && loopc < ncliprect ) {
+	while ( loopc >=0 && loopc < this->ncliprect ) {
 
-	    int ylevel = cliprect[loopc].y();
+	    int ylevel = this->cliprect[loopc].y();
 	    if ( dx != dy ) {
 		// find other end of strip
-		while ( loopc >=0 && loopc < ncliprect
-			&& cliprect[loopc].y() == ylevel )
+		while ( loopc >=0 && loopc < this->ncliprect
+			&& this->cliprect[loopc].y() == ylevel )
 		    loopc -= dx;
 		loopc += dx;
 	    }
 	    int end_of_strip = loopc;
 	    do {
 
-		do_scissors(cliprect[loopc]);
+		do_scissors(this->cliprect[loopc]);
 
 		int tw=w;
 		int th=h;
 		int start,end;
 		int typ=yp;
 
-		int src_pixel_linestep=(srclinestep*8)/srcdepth;
+		int src_pixel_linestep=(this->srclinestep*8)/this->srcdepth;
 
 		if ( !rev ) {
 		    matrox_regw(AR5,src_pixel_linestep);
@@ -554,7 +554,7 @@ inline void QGfxMatrox<depth,type>::blt(int rx,int ry,int w,int h,int sx,int sy)
 		matrox_regw(AR3,start);
 		matrox_regw(FXBNDRY,((xp+tw)<<16) | xp);
 		int p=typ;
-		int t=linestep();
+		int t=this->linestep();
 		t=(t*8)/depth;
 		//t&=0x1f;
 		p*=(t >> 5);
@@ -562,15 +562,15 @@ inline void QGfxMatrox<depth,type>::blt(int rx,int ry,int w,int h,int sx,int sy)
 		matrox_regw(LEN | EXEC,th);
 
 		loopc += dx;
-	    } while ( loopc >= 0 && loopc < ncliprect &&
-		      cliprect[loopc].y() == ylevel );
+	    } while ( loopc >= 0 && loopc < this->ncliprect &&
+		      this->cliprect[loopc].y() == ylevel );
 
 	    //find next strip
 	    if ( dx != dy )
 		loopc = end_of_strip - dx;
 
 	}
-	QRect r(0,0,width,height);
+	QRect r(0,0,this->width,this->height);
 	do_scissors(r);
 	
 	GFX_END
