@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qgfxrepeater_qws.cpp   3.3.2   edited May 27 2003 $
+** $Id: qt/qgfxrepeater_qws.cpp   3.3.4   edited Oct 22 10:48 $
 **
 ** ...
 **
@@ -61,6 +61,7 @@ public:
 
 };
 
+#ifndef QT_NO_QWS_CURSOR
 class QCursorRec {
 
 public:
@@ -70,9 +71,11 @@ public:
     int w;
     int h;
     QScreenCursor * cursor;
+    QScreen *screen;
     bool visible;
 
 };
+#endif
 
 class QRepeaterGfx : public QGfx {
 
@@ -86,7 +89,6 @@ public:
     virtual void setWidgetDeviceRegion(const QRegion &);
 
     virtual void setPen(const QPen &);
-    virtual void setFont(const QFont &);
     virtual void setBrush(const QBrush &);
     virtual void setBrushPixmap(const QPixmap *);
     virtual void setBrushOffset (int, int);
@@ -123,7 +125,7 @@ public:
     virtual void setAlphaType (AlphaType);
     virtual void setAlphaSource (unsigned char *, int);
     virtual void setAlphaSource (int, int = -1, int = -1, int = -1);
-    virtual void drawText (int, int, const QString &);
+    virtual void drawGlyphs( QMemoryManager::FontID font, glyph_t *glyphs, QPoint *positions, int num_glyphs );
     virtual void setClut (QRgb *, int);
     virtual void save ();
     virtual void restore ();
@@ -198,13 +200,6 @@ void QRepeaterGfx::setPen(const QPen & p)
     }
 }
 
-void QRepeaterGfx::setFont(const QFont & f)
-{
-    for(QGfxRec * walker=gfxen.first();walker;walker=gfxen.next()) {
-	walker->gfx->setFont(f);
-    }
-}
-
 void QRepeaterGfx::setBrush(const QBrush & b)
 {
     for(QGfxRec * walker=gfxen.first();walker;walker=gfxen.next()) {
@@ -502,17 +497,17 @@ void QRepeaterGfx::setAlphaSource (unsigned char * c, int i)
     }
 }
 
-void QRepeaterGfx::setAlphaSource (int a, int b = -1, int c= -1, int d = -1)
+void QRepeaterGfx::setAlphaSource (int a, int b, int c, int d)
 {
     for(QGfxRec * walker=gfxen.first();walker;walker=gfxen.next()) {
 	walker->gfx->setAlphaSource(a,b,c,d);
     }
 }
 
-void QRepeaterGfx::drawText (int x, int y, const QString & s)
+void QRepeaterGfx::drawGlyphs( QMemoryManager::FontID font, glyph_t *glyphs, QPoint *positions, int num_glyphs )
 {
     for(QGfxRec * walker=gfxen.first();walker;walker=gfxen.next()) {
-	walker->gfx->drawText(x,y,s);
+	walker->gfx->drawGlyphs(font, glyphs, positions, num_glyphs);
     }
 }
 
@@ -544,6 +539,7 @@ void QRepeaterGfx::setRop (Qt::RasterOp r)
     }
 }
 
+#ifndef QT_NO_QWS_CURSOR
 class QRepeaterCursor : public QScreenCursor
 {
 
@@ -577,6 +573,7 @@ private:
     QPtrList<QCursorRec> cursors;
 
 };
+#endif
 
 class QScreenRec {
 
@@ -637,13 +634,14 @@ QImage * QRepeaterScreen::readScreen(int x,int y,int w,int h,QRegion & r)
 
     QGfx * gfx=ret->graphicsContext();
     r=QRegion(QRect(x,y,w,h));
+#ifndef QT_NO_QWS_CURSOR
     QRepeaterCursor * qrc=(QRepeaterCursor *)qt_screencursor;
     if((qrc->visible) && sw_cursor_exists && QRect(x,y,w,h).intersects
        (QRect(qrc->xpos,qrc->ypos,32,32))) {
 	qt_screencursor->hide();
 	did_hide=true;
     }
-
+#endif
     for(walker=screens.first();walker;walker=screens.next()) {
 	QRect r2(walker->xoffs,walker->yoffs,walker->screen->width(),
 		 walker->screen->height());
@@ -660,11 +658,11 @@ QImage * QRepeaterScreen::readScreen(int x,int y,int w,int h,QRegion & r)
 	}
     }
     delete gfx;
-
+#ifndef QT_NO_QWS_CURSOR
     if(did_hide) {
 	qt_screencursor->show();
     }
-
+#endif
     return ret;
 }
 
@@ -735,6 +733,7 @@ QRepeaterScreen::QRepeaterScreen(int)
 
 int QRepeaterScreen::initCursor(void * v,bool b)
 {
+#ifndef QT_NO_QWS_CURSOR
     QRepeaterCursor * qrc=new QRepeaterCursor();
     unsigned char * c=(unsigned char *)v;
     QScreenRec * walker;
@@ -742,6 +741,7 @@ int QRepeaterScreen::initCursor(void * v,bool b)
     QScreen * tmp=qt_screen;
     for(walker=screens.first();walker;walker=screens.next()) {
 	qt_screen=walker->screen;
+	qt_screencursor = 0;
 	int am=walker->screen->initCursor((void *)c,b);
 	walker->cursor=qt_screencursor;
 	c-=am;
@@ -751,6 +751,9 @@ int QRepeaterScreen::initCursor(void * v,bool b)
     qt_screencursor=qrc;
     qt_screen=tmp;
     return count;
+#else
+    return 0;
+#endif
 }
 
 QRepeaterScreen::~QRepeaterScreen()
@@ -831,6 +834,7 @@ QGfx * QRepeaterScreen::createGfx(uchar * buffer,int w,int h,int d,
     }
 }
 
+#ifndef QT_NO_QWS_CURSOR
 QRepeaterCursor::QRepeaterCursor()
 {
     visible=false;
@@ -852,7 +856,8 @@ void QRepeaterCursor::addScreen(QScreen * s,int x,int y)
     tmp->w=s->width();
     tmp->h=s->height();
     tmp->visible=false;
-    tmp->cursor=qt_screencursor;
+    tmp->cursor= tmp->cursor=qt_screencursor;
+     tmp->screen=s;
     cursors.append(tmp);
 }
 
@@ -864,17 +869,26 @@ void QRepeaterCursor::init(SWCursorData *,bool)
 void QRepeaterCursor::set(const QImage &image,int hotx,int hoty)
 {
     QCursorRec * walker;
+    QScreen * tmp=qt_screen;
     for(walker=cursors.first();walker;walker=cursors.next()) {
-	walker->cursor->set(image,hotx,hoty);
+        if (walker->cursor) {
+            qt_screen = walker->screen;
+            walker->cursor->set(image,hotx,hoty);
+        }
     }
+    qt_screen = tmp;
 }
 
 void QRepeaterCursor::move(int x,int y)
 {
     QCursorRec * walker;
+    QScreen * tmp=qt_screen;
+
     for(walker=cursors.first();walker;walker=cursors.next()) {
 	int xx=x-(walker->xoffs);
 	int yy=y-(walker->yoffs);
+	if (walker->cursor) {
+	    qt_screen = walker->screen;
 	if(xx<0 || yy<0 || xx>walker->w || yy>walker->h) {
 	    walker->cursor->hide();
 	    walker->cursor->move(walker->w,walker->h);
@@ -885,30 +899,41 @@ void QRepeaterCursor::move(int x,int y)
 		walker->cursor->show();
 	    walker->cursor->move(xx,yy);
 	}
+        }
     }
     xpos=x;
     ypos=y;
+    qt_screen=tmp;
 }
 
 void QRepeaterCursor::show()
 {
+    QScreen * tmp=qt_screen;
     QCursorRec * walker;
     for(walker=cursors.first();walker;walker=cursors.next()) {
-	if(walker->visible)
+	if(walker->visible&&walker->cursor) {
+	    qt_screen=walker->screen;
 	    walker->cursor->show();
-   }
+        }
+    }
+    qt_screen=tmp;
     visible=true;
 }
 
 void QRepeaterCursor::hide()
 {
     QCursorRec * walker;
+    QScreen * tmp=qt_screen;
     for(walker=cursors.first();walker;walker=cursors.next()) {
-	if(walker->visible)
+	if(walker->visible&&walker->cursor) {
+	    qt_screen=walker->screen;
 	    walker->cursor->hide();
+	}
     }
+    qt_screen=tmp;
     visible=false;
 }
+#endif //QT_NO_QWS_CURSOR
 
 void QRepeaterGfx::scroll (int x, int y, int w, int h, int sx, int sy)
 {
