@@ -1,5 +1,5 @@
 /*****************************************************************************
-** $Id: qt/qgfxvnc_qws.cpp   3.3.2   edited Mar 31 12:03 $
+** $Id: qt/qgfxvnc_qws.cpp   3.3.4   edited Jul 13 2004 $
 **
 ** Implementation of QGfxvnc (remote frame buffer driver)
 ** Proof of concept driver only, but quite complete.
@@ -59,7 +59,6 @@ struct QVNCHeader
     uchar map[MAP_HEIGHT][MAP_WIDTH];
 };
 
-static QVNCScreen *qvnc_screen = 0;
 
 //===========================================================================
 
@@ -168,8 +167,7 @@ class QVNCServer : public QServerSocket
 {
     Q_OBJECT
 public:
-    QVNCServer();
-    QVNCServer( int id );
+    QVNCServer( QVNCScreen *screen, int id = 0 );
     ~QVNCServer();
 
     virtual void newConnection( int socket );
@@ -216,6 +214,8 @@ private:
     bool supportHextile;
     bool wantUpdate;
     int nibble;
+
+    QVNCScreen *qvnc_screen;
 };
 
 //===========================================================================
@@ -484,24 +484,10 @@ bool QRfbClientCutText::read( QSocket *s )
 
 //===========================================================================
 
-/*
- */
-QVNCServer::QVNCServer()
-    : QServerSocket( (Q_UINT16)5900 )
-{
-    qDebug( "QVNCServer created" );
-    handleMsg = FALSE;
-    client = 0;
-    encodingsPending = 0;
-    cutTextPending = 0;
-    keymod = 0;
-    timer = new QTimer( this );
-    connect( timer, SIGNAL(timeout()), this, SLOT(checkUpdate()) );
-}
-
-QVNCServer::QVNCServer( int id )
+QVNCServer::QVNCServer( QVNCScreen *screen, int id )
     : QServerSocket( (Q_UINT16)(5900 + id) )
 {
+    qvnc_screen = screen;
     qDebug( "QVNCServer created" );
     handleMsg = FALSE;
     client = 0;
@@ -872,9 +858,47 @@ int QVNCServer::getPixel( uchar **data )
     g >>= (8 - pixelFormat.greenBits);
     b >>= (8 - pixelFormat.blueBits);
 
-    return (r << pixelFormat.redShift) |
-	   (g << pixelFormat.greenShift) |
-	   (b << pixelFormat.blueShift);
+    int pixel = (r << pixelFormat.redShift) |
+	        (g << pixelFormat.greenShift) |
+	        (b << pixelFormat.blueShift);
+    
+    if ( QImage::systemByteOrder() == QImage::BigEndian ) { // server runs on a big endian system
+    	if ( pixelFormat.bitsPerPixel == 16 ) {
+            if ( pixelFormat.bigEndian ) { // client expects big endian
+            	pixel = ((pixel & 0x0000ffff) << 16);
+            } else { // client expects little endian
+            	pixel = (((pixel & 0x0000ff00) << 8)  | 
+                         ((pixel & 0x000000ff) << 24));
+            }
+        } else if ( pixelFormat.bitsPerPixel == 32 ) { 
+            if ( !pixelFormat.bigEndian ) { // client expects little endian
+                pixel = (((pixel & 0xff000000) >> 24) | 
+                         ((pixel & 0x00ff0000) >> 8)  | 
+                         ((pixel & 0x0000ff00) << 8)  | 
+                         ((pixel & 0x000000ff) << 24));
+            }
+        } else {
+	    qDebug( "Cannot handle %d bpp client", pixelFormat.bitsPerPixel );
+        }
+    } else { // server runs on a little endian system
+    	if ( pixelFormat.bitsPerPixel == 16 ) {
+            if ( pixelFormat.bigEndian ) { // client expects big endian
+            	pixel = (((pixel & 0xff000000) >> 8) | 
+                         ((pixel & 0x00ff0000) << 8));
+            }
+        } else if ( pixelFormat.bitsPerPixel == 32 ) { 
+            if ( pixelFormat.bigEndian ) { // client expects big endian
+                pixel = (((pixel & 0xff000000) >> 24) | 
+                         ((pixel & 0x00ff0000) >> 8)  | 
+                         ((pixel & 0x0000ff00) << 8)  | 
+                         ((pixel & 0x000000ff) << 24));
+            }
+        } else {
+	    qDebug( "Cannot handle %d bpp client", pixelFormat.bitsPerPixel );
+        }
+    }
+    
+    return pixel;
 }
 
 /*
@@ -1052,13 +1076,15 @@ void QVNCServer::discardClient()
 class QVNCScreenCursor : public QScreenCursor
 {
 public:
-    QVNCScreenCursor();
+    QVNCScreenCursor( QVNCScreen *screen );
 
     virtual void set( const QImage &image, int hotx, int hoty );
     virtual void move( int x, int y );
+private:
+    QVNCScreen *qvnc_screen;
 };
 
-QVNCScreenCursor::QVNCScreenCursor() : QScreenCursor()
+QVNCScreenCursor::QVNCScreenCursor( QVNCScreen *screen ) : QScreenCursor(), qvnc_screen(screen)
 {
 }
 
@@ -1087,7 +1113,7 @@ template <const int depth, const int type>
 class QGfxVNC : public QGfxRaster<depth,type>
 {
 public:
-    QGfxVNC(unsigned char *b,int w,int h);
+    QGfxVNC(QVNCScreen *screen, unsigned char *b,int w,int h);
     virtual ~QGfxVNC();
 
     virtual void drawPoint( int,int );
@@ -1102,11 +1128,13 @@ public:
     virtual void stretchBlt( int,int,int,int,int,int );
 #endif
     virtual void tiledBlt( int,int,int,int );
+
+    QVNCScreen *qvnc_screen;
 };
 
 template <const int depth, const int type>
-QGfxVNC<depth,type>::QGfxVNC(unsigned char *b,int w,int h)
-    : QGfxRaster<depth, type>( b, w, h )
+QGfxVNC<depth,type>::QGfxVNC(QVNCScreen *screen, unsigned char *b,int w,int h)
+    : QGfxRaster<depth, type>( b, w, h ), qvnc_screen(screen)
 {
 }
 
@@ -1227,7 +1255,6 @@ void QGfxVNC<depth,type>::tiledBlt( int x,int y,int w,int h )
 QVNCScreen::QVNCScreen( int display_id ) : VNCSCREEN_BASE( display_id )
 {
     virtualBuffer = FALSE;
-    qvnc_screen = this;
     shm = 0;
 }
 
@@ -1285,7 +1312,7 @@ bool QVNCScreen::connect( const QString &displaySpec )
 	tmpSpec.remove (0, next + 1);
 	VNCSCREEN_BASE::connect( tmpSpec );
     }
-    shm = new QSharedMemory(sizeof(QVNCHeader) + vsize + 8, qws_qtePipeFilename().append('a'));
+    shm = new QSharedMemory( sizeof(QVNCHeader) + vsize + 8, qws_qtePipeFilename(), 'v'+displayId );
     if (!shm->create())
 	qDebug("create");
     if (!shm->attach())
@@ -1317,10 +1344,10 @@ bool QVNCScreen::initDevice()
 	    screenclut[idx]=qRgb( val, val, val );
 	}
     }
-    vncServer = new QVNCServer();
+    vncServer = new QVNCServer(this, displayId);
 
     hdr->dirty = FALSE;
-    memset( qvnc_screen->hdr->map, 0, MAP_WIDTH*MAP_HEIGHT );
+    memset( hdr->map, 0, MAP_WIDTH*MAP_HEIGHT );
 
     return TRUE;
 }
@@ -1339,7 +1366,7 @@ int QVNCScreen::initCursor(void* e, bool init)
     // ### until QLumpManager works Ok with multiple connected clients,
     // we steal a chunk of shared memory
     SWCursorData *data = (SWCursorData *)e - 1;
-    qt_screencursor=new QVNCScreenCursor();
+    qt_screencursor=new QVNCScreenCursor(this);
     qt_screencursor->init( data, init );
     return sizeof(SWCursorData);
 #else
@@ -1375,28 +1402,28 @@ QGfx * QVNCScreen::createGfx(unsigned char * bytes,int w,int h,int d, int linest
 #ifndef QT_NO_QWS_DEPTH_16
     } else if(d==16) {
 	if ( bytes == qt_screen->base() )
-	    ret = new QGfxVNC<16,0>(bytes,w,h);
+	    ret = new QGfxVNC<16,0>(this,bytes,w,h);
 	else
 	    ret = new QGfxRaster<16,0>(bytes,w,h);
 #endif
 #ifndef QT_NO_QWS_DEPTH_8
     } else if (d==8) {
 	if ( bytes == qt_screen->base() )
-	    ret = new QGfxVNC<8,0>(bytes,w,h);
+	    ret = new QGfxVNC<8,0>(this,bytes,w,h);
 	else
 	    ret = new QGfxRaster<8,0>(bytes,w,h);
 #endif
 #ifndef QT_NO_QWS_DEPTH_32
     } else if (d==32) {
 	if ( bytes == qt_screen->base() )
-	    ret = new QGfxVNC<32,0>(bytes,w,h);
+	    ret = new QGfxVNC<32,0>(this,bytes,w,h);
 	else
 	    ret = new QGfxRaster<32,0>(bytes,w,h);
 #endif
 #ifndef QT_NO_QWS_DEPTH_4
     } else if (d==4) {
 	if ( bytes == qt_screen->base() )
-	    ret = new QGfxVNC<4,0>(bytes,w,h);
+	    ret = new QGfxVNC<4,0>(this,bytes,w,h);
 	else
 	    ret = new QGfxRaster<4,0>(bytes,w,h);
 #endif
