@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qapplication_qws.cpp   3.3.2   edited Feb 17 17:18 $
+** $Id: qt/qapplication_qws.cpp   3.3.4   edited Nov 30 10:46 $
 **
 ** Implementation of Qt/FB startup routines and event handling
 **
@@ -2763,7 +2763,7 @@ bool QETWidget::translateMouseEvent( const QWSMouseEvent *event, int oldstate )
 #ifndef QT_NO_QWS_MANAGER
 	    if (widget->isTopLevel() && widget->topData()->qwsManager
 		&& (widget->topData()->qwsManager->region().contains(globalPos)
-		    || (QWSManager::grabbedMouse() && QWidget::mouseGrabber())) ) {
+		    || QWSManager::grabbedMouse()) ) {
 		if ( (*mouseInWidget) ) {
 		    QEvent leave( QEvent::Leave );
 		    QApplication::sendSpontaneousEvent( *mouseInWidget, &leave );
