@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qpainter_qws.cpp   3.3.2   edited Oct 27 17:35 $
+** $Id: qt/qpainter_qws.cpp   3.3.4   edited Jul 26 09:36 $
 **
 ** Implementation of QPainter class for Qt/Embedded
 **
@@ -248,8 +248,10 @@ void QPainter::updateFont()
 {
     clearf(DirtyFont);
     if(testf(ExtDev)) {
-	if ( pfont ) delete pfont;
-	pfont = new QFont( cfont.d, pdev );
+        if (pdev->devType() == QInternal::Printer) {
+            if ( pfont ) delete pfont;
+            pfont = new QFont( cfont.d, pdev );
+        }
 	QPDevCmdParam param[1];
 	param[0].font = &cfont;
 	if ( !pdev->cmd(QPaintDevice::PdcSetFont, this, param) )
@@ -545,7 +547,7 @@ bool QPainter::end()				// end painting
     if ( paintEventSaveRegion )
 	*paintEventSaveRegion = QRegion();
 
-    if ( pdev->devType() == QInternal::Widget )
+    if ( pdev && pdev->devType() == QInternal::Widget )
 	widgetPainterList->removeRef( this );
 
     delete gfx;
@@ -559,11 +561,59 @@ bool QPainter::end()				// end painting
 	QFontCache::instance->cleanupPrinterFonts();
 
     flags = 0;
-    pdev->painters--;
-    pdev = 0;
+    if ( pdev ) {
+        pdev->painters--;
+        pdev = 0;
+    }
     return TRUE;
 }
 
+#ifdef QT_QWS_EXPERIMENTAL_SCREENPAINTER
+bool QPainter::begin(QScreen *screen)
+{
+    if ( isActive() ) {				// already active painting
+#if defined(QT_CHECK_STATE)
+	qWarning( "QPainter::begin: Painter is already active."
+                  "\n\tYou must end() the painter before a second begin()" );
+#endif
+	return FALSE;
+    }
+    bool reinit = flags != IsStartingUp;	// 2nd or 3rd etc. time called
+    flags = IsActive | DirtyFont;		// init flags
+    gfx =  screen->screenGfx();
+    bro = QPoint( 0, 0 );
+    d->curPt = QPoint( 0, 0 );
+    if ( reinit ) {
+	bg_mode = TransparentMode;		// default background mode
+	rop = CopyROP;				// default ROP
+#ifndef QT_NO_TRANSFORMATIONS
+	wxmat.reset();				// reset world xform matrix
+	xmat.reset();
+	ixmat.reset();
+	txop = txinv = 0;
+#else
+	xlatex = xlatey = 0;
+#endif
+	QFont  defaultFont;			// default drawing tools
+	QPen   defaultPen;
+	QBrush defaultBrush;
+	cfont  = defaultFont;		// set these drawing tools
+	cpen   = defaultPen;
+	cbrush = defaultBrush;
+	bg_col = white;			// default background color
+    }
+#ifndef QT_NO_TRANSFORMATIONS
+    wx = wy = vx = vy = 0;			// default view origins
+#endif
+    ww = vw = screen->width();			// default view size
+    wh = vh = screen->height();
+    gfx->setWidgetRegion( QRect(0,0,ww,wh) );
+    setBackgroundColor( bg_col );
+    updateBrush();
+    updatePen();
+    return TRUE;
+}
+#endif //QT_QWS_EXPERIMENTAL_SCREENPAINTER
 
 void QPainter::flush(const QRegion &, CoordinateMode)
 {
