@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qpixmap_qws.cpp   3.3.2   edited Feb 9 12:21 $
+** $Id: qt/qpixmap_qws.cpp   3.3.4   edited Jan 20 11:59 $
 **
 ** Implementation of QPixmap class for FB
 **
@@ -360,10 +360,9 @@ QPixmap::QPixmap( int w, int h, const uchar *bits, bool isXbitmap )
 
 void QPixmap::detach()
 {
-    if ( data->uninit || data->count == 1 )
-	data->uninit = FALSE;
-    else
-	*this = copy();
+    if ( data->count != 1 )
+        *this = copy();
+    data->uninit = FALSE;
 }
 
 
