@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qregion_qws.cpp   3.3.2   edited Oct 23 14:57 $
+** $Id: qt/qregion_qws.cpp   3.3.4   edited Sep 24 11:28 $
 **
 ** Implementation of QRegion class for FB
 **
@@ -868,7 +868,7 @@ miCoalesce (register Region pReg, int prevStart, int curStart)
 	curStart = pRegEnd - pReg->rects.data();
 	pRegEnd = pReg->rects.data() + pReg->numRects;
     }
-	
+
     if ((curNumRects == prevNumRects) && (curNumRects != 0)) {
 	pCurBox -= curNumRects;
 	/*
@@ -936,7 +936,7 @@ miCoalesce (register Region pReg, int prevStart, int curStart)
 		    *pPrevBox++ = *pCurBox++;
 		} while (pCurBox != pRegEnd);
 	    }
-	
+
 	}
     }
     return (curStart);
@@ -1074,13 +1074,13 @@ miRegionOp(register Region newReg, Region reg1, Region reg2,
 	{
 	    r1BandEnd++;
 	}
-	
+
 	r2BandEnd = r2;
 	while ((r2BandEnd != r2End) && (r2BandEnd->top() == r2->top()))
 	{
 	    r2BandEnd++;
 	}
-	
+
 	/*
 	 * First handle the band that doesn't intersect, if any.
 	 *
@@ -1140,7 +1140,7 @@ miRegionOp(register Region newReg, Region reg1, Region reg2,
 	    (* overlapFunc) (newReg, r1, r1BandEnd, r2, r2BandEnd, ytop, ybot);
 
 	}
-	
+
 	if (newReg->numRects != curBand)
 	{
 	    prevBand = miCoalesce (newReg, prevBand, curBand);
@@ -1439,9 +1439,9 @@ miSubtractNonO1 (register Region pReg, register QRect *r,
 		 QRect *rEnd, register int y1, register int y2)
 {
     register QRect *pNextRect;
-	
+
     pNextRect = pReg->rects.data() + pReg->numRects;
-	
+
     Q_ASSERT(y1<=y2);
 
     while (r != rEnd)
@@ -1586,7 +1586,7 @@ miSubtractO (register Region pReg, register QRect *r1, QRect *r1End,
     }
     return 0;	/* lint */
 }
-	
+
 /*-
  *-----------------------------------------------------------------------
  * miSubtract --
@@ -1659,7 +1659,7 @@ XEmptyRegion( Region r )
 }
 
 /*
- *	Check to see if two regions are equal	
+ *	Check to see if two regions are equal
  */
 static
 int
@@ -2674,7 +2674,7 @@ XPolygonRegion(XPoint *Pts, int Count, int rule)
             }
         }
     }
-    FreeStorage(SLLBlock.next);	
+    FreeStorage(SLLBlock.next);
     (void) PtsToRegion(numFullPtBlocks, iPts, &FirstPtBlock, region);
     for (curPtBlock = FirstPtBlock.next; --numFullPtBlocks >= 0;) {
 	tmpPtBlock = curPtBlock->next;
@@ -2742,7 +2742,7 @@ QRegion::QRegion( const QRect &r, RegionType t )
 
 QRegion::QRegion( const QPointArray &a, bool winding )
 {
-    if ( a.isEmpty() ) {
+    if ( a.count() < 3 ) {
 	if ( !empty_region ) {			// avoid too many allocs
 	    qAddPostRoutine( cleanup_empty_region );
 	    empty_region = new QRegion( TRUE );
