@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qwidget_qws.cpp   3.3.2   edited Feb 4 16:58 $
+** $Id: qt/qwidget_qws.cpp   3.3.4   edited Jan 18 17:23 $
 **
 ** Implementation of QWidget and QWindow classes for FB
 **
@@ -299,9 +299,9 @@ void QWidget::create( WId window, bool initializeWindow, bool /*destroyOldWindow
 	    delete topData()->qwsManager;
 	    topData()->qwsManager = 0;
 	    crect.moveBy( -extra->topextra->fleft, -extra->topextra->ftop );
-	    extra->topextra->fleft = extra->topextra->ftop = 
+	    extra->topextra->fleft = extra->topextra->ftop =
 		extra->topextra->fright = extra->topextra->fbottom = 0;
-	}	    
+	}
 #endif
 	// declare the widget's object name as window role
 
@@ -347,7 +347,13 @@ void QWidget::destroy( bool destroyWindow, bool destroySubWindows )
 	releaseMouse();
 	if ( qt_pressGrab == this )
 	  qt_pressGrab = 0;
-
+#ifndef QT_NO_QWS_MANAGER
+	if (QWSManager::grabbedMouse() == this) {
+	    if ( extra && extra->topextra && extra->topextra->qwsManager ) {
+		extra->topextra->qwsManager->releaseGrab();
+	    }
+	}
+#endif
 	if ( keyboardGrb == this )
 	    releaseKeyboard();
 	if ( testWFlags(WShowModal) )		// just be sure we leave modal
@@ -770,6 +776,13 @@ void QWidget::hideWindow()
 
     if ( testWFlags(WType_TopLevel) ) {
 	releaseMouse();
+#ifndef QT_NO_QWS_MANAGER
+	if (QWSManager::grabbedMouse() == this) {
+	    if ( extra && extra->topextra && extra->topextra->qwsManager ) {
+		extra->topextra->qwsManager->releaseGrab();
+	    }
+	}
+#endif
 	qwsDisplay()->requestRegion(winId(), QRegion());
 	qwsDisplay()->requestFocus(winId(),FALSE);
     } else {
@@ -797,12 +810,13 @@ static uint effectiveState(uint state)
 	return Qt::WState_FullScreen;
     if ( state & Qt::WState_Maximized )
 	return Qt::WState_Maximized;
-    
+
     return 0;
 }
 
 void QWidget::setWindowState(uint newstate)
 {
+    in_show_maximized = 1;
     bool resized = testWFlags( WState_Resized );
     uint oldstate = effectiveState(widget_state);
 
@@ -862,7 +876,9 @@ void QWidget::setWindowState(uint newstate)
 	    }
 	}
     }
-    
+
+    in_show_maximized = 0;
+
     if (needShow)
 	show();
 
@@ -879,7 +895,7 @@ void QWidget::raise()
     if ( p && p->childObjects && p->childObjects->findRef(this) >= 0 )
 	p->childObjects->append( p->childObjects->take() );
     if ( isTopLevel() ) {
-#ifdef QT_NO_WINDOWGROUPHINT	
+#ifdef QT_NO_WINDOWGROUPHINT
 	if ( !testWFlags( WStyle_Tool ) )
 	    setActiveWindow();
 	qwsDisplay()->setAltitude( winId(), 0 );
@@ -1001,10 +1017,12 @@ void QWidget::internalSetGeometry( int x, int y, int w, int h, bool isMove )
 	oldAlloc = allocatedRegion();
     }
 
-    clearWState(WState_Maximized);
-    clearWState(WState_FullScreen);
-    if (isTopLevel())
-	topData()->normalGeometry = QRect(0, 0, -1, -1);
+    if (!in_show_maximized) {
+        clearWState(WState_Maximized);
+        clearWState(WState_FullScreen);
+        if (isTopLevel())
+            topData()->normalGeometry = QRect(0, 0, -1, -1);
+    }
     QPoint oldPos = pos();
     crect = r;
 
@@ -1671,13 +1689,13 @@ QRegion QWidget::paintableRegion() const
 
 void QWidget::setMask( const QRegion& region )
 {
-    alloc_region_dirty = TRUE;
-
     createExtra();
 
-    if ( region.isNull() && extra->mask.isNull() )
+    if ( region == extra->mask )
 	return;
 
+    alloc_region_dirty = TRUE;
+
     extra->mask = region;
 
     if ( isTopLevel() ) {
@@ -1800,7 +1818,8 @@ int QWidget::bytesPerLine() const
 void QWidget::resetInputContext()
 {
 #ifndef QT_NO_QWS_IM
-    QInputContext::reset();
+    if (hasFocus())
+        QInputContext::reset();
 #endif
 }
 
