@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: qt/qwindowsystem_qws.cpp   3.3.2   edited Nov 13 18:08 $
+** $Id: qt/qwindowsystem_qws.cpp   3.3.4   edited May 21 2004 $
 **
 ** Implementation of Qt/FB central server
 **
@@ -1836,8 +1836,12 @@ void QWSServer::setCurrentInputMethod( QWSInputMethod *im )
 */
 void QWSServer::sendPropertyNotifyEvent( int property, int state )
 {
-    for ( ClientIterator it = client.begin(); it != client.end(); ++it )
-	( *it )->sendPropertyNotifyEvent( property, state );
+    ClientIterator it = client.begin();
+    while ( it != client.end() ) {
+        QWSClient *cl = *it;
+        ++it;
+        cl->sendPropertyNotifyEvent( property, state );
+    }
 }
 #endif
 void QWSServer::invokeIdentify( const QWSIdentifyCommand *cmd, QWSClient *client )
